@@ -1,7 +1,7 @@
 package App::perlmv::u;
 
 our $DATE = '2017-08-01'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -215,6 +215,9 @@ sub perlmv {
             return [412, "Can't rename '$file' to '$absnew0': ".
                         "path does not exist"];
         }
+        if ($absnew0 eq $absfile) {
+            next;
+        }
         my $absnew;
         my $i = 0;
         while (1) {
@@ -381,7 +384,7 @@ App::perlmv::u - Rename files using Perl code, with undo/redo
 
 =head1 VERSION
 
-This document describes version 0.002 of App::perlmv::u (from Perl distribution App-perlmv-u), released on 2017-08-01.
+This document describes version 0.003 of App::perlmv::u (from Perl distribution App-perlmv-u), released on 2017-08-01.
 
 =head1 DESCRIPTION
 
